package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.SysOrg;
import com.example.civilizedcity.service.SysOrgService;

 /**
 * 单位表;(sys_org)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-12-12
 */
@Api(tags = "单位表对象功能接口")
@RestController
@RequestMapping("/")
public class SysOrgController extends BaseController {
    
    @Autowired
    private SysOrgService sysOrgService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param orgId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysOrg/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(sysOrgService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/sysOrg")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<SysOrg> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<SysOrg> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<SysOrg> result = sysOrgService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param sysOrg 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/sysOrg")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody SysOrg sysOrg) throws Exception {
        sysOrgService.save(sysOrg);
        return ResponseBean.success(sysOrg);
    }
    
    /** 
     * 更新数据
     *
     * @param sysOrg 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/sysOrg/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody SysOrg sysOrg,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        sysOrgService.updateById(sysOrg);
        return ResponseBean.success(sysOrg);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param orgId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysOrg/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        sysOrgService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}