package com.example.civilizedcity.service.impl;

import com.example.civilizedcity.common.Constants;
import com.example.civilizedcity.common.EncryptUtils;
import com.example.civilizedcity.common.StringUtils;
import com.example.civilizedcity.entity.SysLogin;
import com.example.civilizedcity.mapper.SysLoginMapper;
import com.example.civilizedcity.vo.ChangePassword;
import com.example.civilizedcity.vo.LoginParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.example.civilizedcity.entity.SysUser;
import com.example.civilizedcity.mapper.SysUserMapper;
import com.example.civilizedcity.service.SysUserService;

/**
 * 用户表;(sys_user)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2022-12-12
 */
@Service
public class SysUserServiceImpl extends BaseServiceImpl<SysUserMapper, SysUser> implements SysUserService {

    @Autowired
    SysLoginMapper sysLoginMapper;

    @Override
    public SysUser login(LoginParam loginParm) throws Exception {
        SysLogin sysLogin = sysLoginMapper.getByAccount(loginParm.getAccount());
        if (null == sysLogin) {
            throw new Exception("用户名或者密码不正确");
        }

        String userId = sysLogin.getUserId();
        if (StringUtils.isEmpty(userId)) {
            throw new Exception("用户名或者密码不正确");
        }

        boolean isRight = checkPassword(loginParm.getPassword(), sysLogin.getPassword(), userId);
        if (!isRight) {
            throw new Exception("用户名或者密码不正确");
        }

        SysUser sysUser = getById(userId);
        if (Constants.STATUS_DELETE == sysUser.getStatus()) {
            throw new Exception("用户账户已删除");
        }

        if (Constants.STATUS_NORMAL != sysUser.getStatus()) {
            throw new Exception("用户已停用");
        }

        return sysUser;
    }

    @Override
    public boolean changePassword(SysUser user, ChangePassword param) throws Exception {
        String passwordEncrypted = EncryptUtils.md5(param.getOriginPassword(), user.getUserId());
        SysLogin sysLogin = sysLoginMapper.getByUserAndPassword(user.getUserId(), passwordEncrypted);

        if (null == sysLogin) {
            throw new Exception("原始密码不正确");
        }

        String newPassword = EncryptUtils.md5(param.getNewPassword(), user.getUserId());
        sysLogin.setPassword(newPassword);

        return sysLoginMapper.updateById(sysLogin) > 0;
    }

    boolean checkPassword(String src, String targ, String salt) {
        String newPass = EncryptUtils.md5(src, salt);
        return targ.equals(newPass);
    }
}